#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Feb 17 15:55:39 2021

@author: anton
"""

from SLiCAP import *
import specs

fileName = "activeAntennaNoise"

prj = initProject('Noise active antenna')

i1 = instruction()
i1.setCircuit(fileName + '.cir')

# Define the parameters form the specifications

i1.defPar("L_A", specs.LA)
i1.defPar("C_0", specs.C0)
i1.setSource('V1')

htmlPage("Circuit data")
head2html("Noise model of the active antenna")
img2html(fileName + ".svg", 600)
netlist2html(fileName + ".cir")
elementData2html(i1.circuit)

htmlPage("Symbolic noise analysis")
head2html("Noise model of the active antenna")
img2html(fileName + ".svg", 600)
i1.setSimType('symbolic')
i1.setGainType('vi')
i1.setDataType('noise')
i1.setSource("V1")
i1.setDetector("V_out")
symNoiseResult = i1.execute()
noise2html(symNoiseResult)

htmlPage("Numeric noise analysis")

head2html("Noise model of the active antenna")
img2html(fileName + ".svg", 600)
i1.setSimType('numeric')

numNoiseResult = i1.execute()
noise2html(numNoiseResult)

htmlPage("Noise show-stopper values")

S_v, S_i = sp.symbols("S_v, S_i")
img2html(fileName + ".svg", 600)
head2html("Floor noise")
text2html("At high frequencies the antenna-referred floor noise should be below " +
          "{:.2e}.".format(specs.SAfloor) + 
          "$\\left[ \\frac{V^2}{m\\,Hz}\\right]$")

floorNoise = sp.limit(numNoiseResult.inoise, ini.frequency, 'oo')
SfloorMax = sp.solve(floorNoise - specs.SAfloor, S_v)[0]

text2html("from this, we obtain the maximum vale $S_{vMax}$ of $S_v$ as:")

eqn2html("S_vMax", SfloorMax, units='V^2/Hz')

text2html("This can be written as: {:.2e}".format(sp.sqrt(SfloorMax)) +
          "$\\left[ \\frac{V}{\\sqrt{Hz}}\\right]$.")

head2html("Low-frequency noise")
text2html("At low frequencies the input-referred current noise of the active " +
          "antenna is the dominant noise source. At low frequencies we have:")

lfNoise =  numNoiseResult.inoise - floorNoise
eqn2html("S_A", lfNoise, units='V^2/m/Hz')

text2html("The maximum value $S_{iMax}$ of $S_i$ is obtained as:")
SiMax = sp.solve(lfNoise.subs(ini.frequency, specs.Flow) - specs.SAlow, S_i)[0]
eqn2html("S_iMax", SiMax, units="A^2/Hz")
text2html("This can be written as: {:.2e}".format(sp.sqrt(SiMax)) +
          "$\\left[ \\frac{A}{\\sqrt{Hz}}\\right]$.")